@@ -137,6 +137,9 @@ url = http://192.168.1.1:8080
 subby=bar
     #another comment
  ; yet another comment
+
+-nonstandard-
+  shoes = purple
       EOS
     }
 
@@ -144,7 +147,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :setting => 'yahoo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -164,15 +167,20 @@ yahoo = yippee
 subby=bar
     #another comment
  ; yet another comment
+
+-nonstandard-
+  shoes = purple
       EOS
 )
     end
 
-    it "should add a missing setting to the correct section with colon" do
+    it "should add a missing setting to the correct section with pre/suffix" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
-          :section => 'section:sub', :setting => 'yahoo', :value => 'yippee'))
+          :section => 'nonstandard',
+          :setting => 'yahoo', :value => 'yippee',
+          :section_prefix => '-', :section_suffix => '-'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -191,6 +199,40 @@ url = http://192.168.1.1:8080
 subby=bar
     #another comment
  ; yet another comment
+
+-nonstandard-
+  shoes = purple
+  yahoo = yippee
+      EOS
+)
+    end
+
+    it "should add a missing setting to the correct section with colon" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+          :section => 'section:sub', :setting => 'yahoo', :value => 'yippee'))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.create
+      validate_file(<<-EOS
+# This is a comment
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = true
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+-nonstandard-
+  shoes = purple
 yahoo = yippee
       EOS
 )
@@ -200,7 +242,7 @@ yahoo = yippee
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
            :setting => 'baz', :value => 'bazvalue2'))
       provider = described_class.new(resource)
-      provider.exists?.should == 'bazvalue'
+      provider.exists?.should be true
       provider.value=('bazvalue2')
       validate_file(<<-EOS
 # This is a comment
@@ -219,6 +261,41 @@ url = http://192.168.1.1:8080
 subby=bar
     #another comment
  ; yet another comment
+
+-nonstandard-
+  shoes = purple
+      EOS
+      )
+    end
+
+    it "should modify an existing setting with pre/suffix with a different value" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+           :section => 'nonstandard',
+           :setting => 'shoes', :value => 'orange',
+           :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be true
+      provider.value=('orange')
+      validate_file(<<-EOS
+# This is a comment
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = true
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+-nonstandard-
+  shoes = orange
       EOS
       )
     end
@@ -227,7 +304,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
            :section => 'section:sub', :setting => 'subby', :value => 'foo'))
       provider = described_class.new(resource)
-      provider.exists?.should == 'bar'
+      provider.exists?.should be true
       provider.value.should == 'bar'
       provider.value=('foo')
       validate_file(<<-EOS
@@ -247,6 +324,9 @@ url = http://192.168.1.1:8080
 subby=foo
     #another comment
  ; yet another comment
+
+-nonstandard-
+  shoes = purple
       EOS
       )
     end
@@ -255,7 +335,7 @@ subby=foo
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
            :setting => 'url', :value => 'http://192.168.0.1:8080'))
       provider = described_class.new(resource)
-      provider.exists?.should == 'http://192.168.1.1:8080'
+      provider.exists?.should be true
       provider.value.should == 'http://192.168.1.1:8080'
       provider.value=('http://192.168.0.1:8080')
 
@@ -276,6 +356,43 @@ url = http://192.168.0.1:8080
 subby=bar
     #another comment
  ; yet another comment
+
+-nonstandard-
+  shoes = purple
+    EOS
+      )
+    end
+
+    it "should be able to handle settings with pre/suffix with non alphanumbering settings " do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+           :section => 'nonstandard',
+           :setting => 'shoes', :value => 'http://192.168.0.1:8080',
+           :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be true
+      provider.value.should == 'purple'
+      provider.value=('http://192.168.0.1:8080')
+
+      validate_file( <<-EOS
+# This is a comment
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = true
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+-nonstandard-
+  shoes = http://192.168.0.1:8080
     EOS
       )
     end
@@ -284,14 +401,23 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
            :setting => 'baz', :value => 'bazvalue'))
       provider = described_class.new(resource)
-      provider.exists?.should == 'bazvalue'
+      provider.exists?.should be true
+    end
+
+    it "should recognize an existing setting with pre/suffix with the specified value" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+           :section => 'nonstandard',
+           :setting => 'shoes', :value => 'purple',
+           :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be true
     end
 
     it "should add a new section if the section does not exist" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => "section3", :setting => 'huzzah', :value => 'shazaam'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -311,17 +437,54 @@ subby=bar
     #another comment
  ; yet another comment
 
+-nonstandard-
+  shoes = purple
+
 [section3]
 huzzah = shazaam
       EOS
       )
     end
 
+    it "should add a new section with pre/suffix if the section does not exist" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+          :section => "section3", :setting => 'huzzah', :value => 'shazaam',
+          :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.create
+      validate_file(<<-EOS
+# This is a comment
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = true
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+-nonstandard-
+  shoes = purple
+
+-section3-
+huzzah = shazaam
+      EOS
+      )
+    end
+
     it "should add a new section if the section does not exist - with colon" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => "section:subsection", :setting => 'huzzah', :value => 'shazaam'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -341,17 +504,54 @@ subby=bar
     #another comment
  ; yet another comment
 
+-nonstandard-
+  shoes = purple
+
 [section:subsection]
 huzzah = shazaam
       EOS
       )
     end
 
+    it "should add a new section with pre/suffix if the section does not exist - with colon" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+          :section => "section:subsection", :setting => 'huzzah', :value => 'shazaam',
+          :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.create
+      validate_file(<<-EOS
+# This is a comment
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = true
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+-nonstandard-
+  shoes = purple
+
+-section:subsection-
+huzzah = shazaam
+      EOS
+      )
+    end
+
     it "should add a new section if no sections exists" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => "section1", :setting => 'setting1', :value => 'hellowworld', :path => emptyfile))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file("
 [section1]
@@ -359,11 +559,24 @@ setting1 = hellowworld
 ", emptyfile)
     end
 
+    it "should add a new section with pre/suffix if no sections exists" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+          :section => "section1", :setting => 'setting1', :value => 'hellowworld', :path => emptyfile,
+          :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.create
+      validate_file("
+-section1-
+setting1 = hellowworld
+", emptyfile)
+    end
+
     it "should add a new section with colon if no sections exists" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => "section:subsection", :setting => 'setting1', :value => 'hellowworld', :path => emptyfile))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file("
 [section:subsection]
@@ -371,11 +584,23 @@ setting1 = hellowworld
 ", emptyfile)
     end
 
+    it "should add a new section with pre/suffix with colon if no sections exists" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+          :section => "section:subsection", :setting => 'setting1', :value => 'hellowworld', :path => emptyfile,
+          :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.create
+      validate_file("
+-section:subsection-
+setting1 = hellowworld
+", emptyfile)
+    end
     it "should be able to handle variables of any type" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => "section1", :setting => 'master', :value => true))
       provider = described_class.new(resource)
-      provider.exists?.should == 'true'
+      provider.exists?.should be true
       provider.value.should == 'true'
     end
 
@@ -397,7 +622,7 @@ foo = http://192.168.1.1:8080
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => '', :setting => 'bar', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -414,7 +639,7 @@ foo = http://192.168.1.1:8080
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
            :section => '', :setting => 'foo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should == 'blah'
+      provider.exists?.should be true
       provider.value.should == 'blah'
       provider.value=('yippee')
       validate_file(<<-EOS
@@ -431,7 +656,7 @@ foo = http://192.168.1.1:8080
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
            :section => '', :setting => 'foo', :value => 'blah'))
       provider = described_class.new(resource)
-      provider.exists?.should == 'blah'
+      provider.exists?.should be true
     end
   end
 
@@ -447,7 +672,7 @@ foo = http://192.168.1.1:8080
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
            :section => '', :setting => 'foo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 foo = yippee
@@ -462,7 +687,7 @@ foo = http://192.168.1.1:8080
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => 'section2', :setting => 'foo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should == 'http://192.168.1.1:8080'
+      provider.exists?.should be true
       provider.value.should == 'http://192.168.1.1:8080'
       provider.value=('yippee')
       validate_file(<<-EOS
@@ -476,7 +701,7 @@ foo = yippee
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => 'section2', :setting => 'bar', :value => 'baz'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 [section2]
@@ -495,26 +720,6 @@ foo=bar
       EOS
     }
 
-    it "should fail if the separator doesn't include an equals sign" do
-      expect {
-        Puppet::Type::Ini_setting.new(common_params.merge(
-                                         :section           => 'section2',
-                                         :setting           => 'foo',
-                                         :value             => 'yippee',
-                                         :key_val_separator => '+'))
-      }.to raise_error Puppet::Error, /must contain exactly one/
-    end
-
-    it "should fail if the separator includes more than one equals sign" do
-      expect {
-        Puppet::Type::Ini_setting.new(common_params.merge(
-                                         :section           => 'section2',
-                                         :setting           => 'foo',
-                                         :value             => 'yippee',
-                                         :key_val_separator => ' = foo = '))
-      }.to raise_error Puppet::Error, /must contain exactly one/
-    end
-
     it "should modify an existing setting" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
                                                    :section           => 'section2',
@@ -522,7 +727,7 @@ foo=bar
                                                    :value             => 'yippee',
                                                    :key_val_separator => '='))
       provider = described_class.new(resource)
-      provider.exists?.should == 'bar'
+      provider.exists?.should be true
       provider.value.should == 'bar'
       provider.value=('yippee')
       validate_file(<<-EOS
@@ -532,25 +737,95 @@ foo=yippee
       )
     end
 
+  end
+
+  context "when overriding the separator to something other than =" do
+    let(:orig_content) {
+      <<-EOS
+[section2]
+foo: bar
+      EOS
+    }
+
+    it "should modify an existing setting" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+                                                   :section           => 'section2',
+                                                   :setting           => 'foo',
+                                                   :value             => 'yippee',
+                                                   :key_val_separator => ': '))
+      provider = described_class.new(resource)
+      provider.exists?.should be true
+      provider.value.should == 'bar'
+      provider.value=('yippee')
+      validate_file(<<-EOS
+[section2]
+foo: yippee
+      EOS
+      )
+    end
+
     it "should add a new setting" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
                                                    :section           => 'section2',
                                                    :setting           => 'bar',
                                                    :value             => 'baz',
-                                                   :key_val_separator => '='))
+                                                   :key_val_separator => ': '))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 [section2]
-foo=bar
-bar=baz
+foo: bar
+bar: baz
       EOS
       )
     end
 
   end
 
+  context "when overriding the separator to a space" do
+    let(:orig_content) {
+      <<-EOS
+[section2]
+foo bar
+      EOS
+    }
+
+    it "should modify an existing setting" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+                                                   :section           => 'section2',
+                                                   :setting           => 'foo',
+                                                   :value             => 'yippee',
+                                                   :key_val_separator => ' '))
+      provider = described_class.new(resource)
+      provider.exists?.should be true
+      provider.value.should == 'bar'
+      provider.value=('yippee')
+      validate_file(<<-EOS
+[section2]
+foo yippee
+      EOS
+      )
+    end
+
+    it "should add a new setting" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+                                                   :section           => 'section2',
+                                                   :setting           => 'bar',
+                                                   :value             => 'baz',
+                                                   :key_val_separator => ' '))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.create
+      validate_file(<<-EOS
+[section2]
+foo bar
+bar baz
+      EOS
+      )
+    end
+  end
+
   context "when ensuring that a setting is absent" do
     let(:orig_content) {
       <<-EOS
@@ -569,6 +844,9 @@ url = http://192.168.1.1:8080
 subby=bar
     #another comment
  ; yet another comment
+
+ -nonstandard-
+   shoes = purple
 EOS
     }
 
@@ -576,7 +854,7 @@ EOS
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
       :section => 'section1', :setting => 'foo', :ensure => 'absent'))
       provider = described_class.new(resource)
-      provider.exists?.should be_true
+      provider.exists?.should be true
       provider.destroy
       validate_file(<<-EOS
 [section1]
@@ -593,15 +871,19 @@ url = http://192.168.1.1:8080
 subby=bar
     #another comment
  ; yet another comment
+
+ -nonstandard-
+   shoes = purple
 EOS
     )
     end
 
-    it "should do nothing for a setting that does not exist" do
+    it "should remove a setting with pre/suffix that exists" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
-                                                   :section => 'section:sub', :setting => 'foo', :ensure => 'absent'))
+      :section => 'nonstandard', :setting => 'shoes', :ensure => 'absent',
+      :section_prefix => '-', :section_suffix => '-' ))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be true
       provider.destroy
       validate_file(<<-EOS
 [section1]
@@ -619,12 +901,72 @@ url = http://192.168.1.1:8080
 subby=bar
     #another comment
  ; yet another comment
+
+ -nonstandard-
+EOS
+    )
+    end
+
+    it "should do nothing for a setting that does not exist" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+                                                   :section => 'section:sub', :setting => 'foo', :ensure => 'absent'))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.destroy
+      validate_file(<<-EOS
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = true
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+ -nonstandard-
+   shoes = purple
+      EOS
+      )
+    end
+
+    it "should do nothing for a setting with pre/suffix that does not exist" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+         :section => 'nonstandard', :setting => 'foo', :ensure => 'absent',
+         :section_prefix => '-', :section_suffix => '-' ))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.destroy
+      validate_file(<<-EOS
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = true
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+ -nonstandard-
+   shoes = purple
       EOS
       )
     end
   end
 
-
   context "when dealing with indentation in sections" do
     let(:orig_content) {
       <<-EOS
@@ -652,7 +994,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
                     :section => 'section1', :setting => 'yahoo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -681,7 +1023,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section1', :setting => 'bar', :value => 'barvalue2'))
       provider = described_class.new(resource)
-      provider.exists?.should be_true
+      provider.exists?.should be true
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -709,7 +1051,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
                                                    :section => 'section2', :setting => 'yahoo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -738,7 +1080,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section2', :setting => 'baz', :value => 'bazvalue2'))
       provider = described_class.new(resource)
-      provider.exists?.should be_true
+      provider.exists?.should be true
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -766,7 +1108,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section:sub', :setting => 'yahoo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be_nil
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -795,7 +1137,7 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section:sub', :setting => 'fleezy', :value => 'flam2'))
       provider = described_class.new(resource)
-      provider.exists?.should be_true
+      provider.exists?.should be true
       provider.create
       validate_file(<<-EOS
 # This is a comment
@@ -842,7 +1184,7 @@ blah = blah
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section2', :setting => 'foo', :value => 'foo3'))
       provider = described_class.new(resource)
-      provider.exists?.should be_false
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
      [section1]
@@ -864,7 +1206,7 @@ blah = blah
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section1', :setting => 'foo', :value => 'foo3'))
       provider = described_class.new(resource)
-      provider.exists?.should be_true
+      provider.exists?.should be true
       provider.create
       validate_file(<<-EOS
      [section1]
@@ -885,7 +1227,7 @@ blah = blah
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section2', :setting => 'bar', :value => 'bar3'))
       provider = described_class.new(resource)
-      provider.exists?.should be_false
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
      [section1]
@@ -907,7 +1249,7 @@ blah = blah
       resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section2', :setting => 'baz', :value => 'bazvalue'))
       provider = described_class.new(resource)
-      provider.exists?.should be_false
+      provider.exists?.should be false
       provider.create
       validate_file(<<-EOS
      [section1]
@@ -938,7 +1280,7 @@ EOS
           common_params.merge(:section => 'section1', :setting => 'foo', :value => 'foovalue2')
         )
         provider = described_class.new(resource)
-        provider.exists?.should be_false
+        provider.exists?.should be false
         provider.create
         validate_file(<<-EOS
 [section1]
@@ -953,7 +1295,7 @@ foo=foovalue2
           common_params.merge(:section => 'section1', :setting => 'bar', :value => 'barvalue2')
         )
         provider = described_class.new(resource)
-        provider.exists?.should be_false
+        provider.exists?.should be false
         provider.create
         validate_file(<<-EOS
 [section1]
@@ -991,7 +1333,7 @@ subby=bar
         resource = Puppet::Type::Ini_setting.new(common_params.merge(
             :section => 'section - two', :setting => 'yahoo', :value => 'yippee'))
         provider = described_class.new(resource)
-        provider.exists?.should be_nil
+        provider.exists?.should be false
         provider.create
         validate_file(<<-EOS
 # This is a comment
@@ -1019,4 +1361,45 @@ subby=bar
 
   end
 
+  context "when sections have spaces and quotations" do
+    let(:orig_content) do
+      <<-EOS
+[branch "master"]
+        remote = origin
+        merge = refs/heads/master
+
+[alias]
+to-deploy = log --merges --grep='pull request' --format='%s (%cN)' origin/production..origin/master
+[branch "production"]
+        remote = origin
+        merge = refs/heads/production
+      EOS
+    end
+
+    it "should add a missing setting to the correct section" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+        :section => 'alias',
+        :setting => 'foo',
+        :value => 'bar'
+      ))
+      provider = described_class.new(resource)
+      provider.exists?.should be false
+      provider.create
+      validate_file(<<-EOS
+[branch "master"]
+        remote = origin
+        merge = refs/heads/master
+
+[alias]
+to-deploy = log --merges --grep='pull request' --format='%s (%cN)' origin/production..origin/master
+foo = bar
+[branch "production"]
+        remote = origin
+        merge = refs/heads/production
+                    EOS
+                   )
+    end
+
+  end
+
 end
